@@ -14,21 +14,25 @@ class Client:
 
         self._credentials = process_token(token)
         self._token = token
-        self._api = API(credentials=self._credentials)
+        self._api = API(credentials=self.credentials)
 
         try:
             self.list_datasets()["datasets"]
         except:
             raise AuthException
         else:
-            print(WELCOME_MESSAGE.format(self._credentials.project))
+            print(WELCOME_MESSAGE.format(self.credentials.project))
 
     @property
     def credentials(self):
         return self._credentials
 
+    @property
+    def api(self) -> API:
+        return self._api
+
     def list_datasets(self):
-        return self._api._list_datasets()
+        return self.api._list_datasets()
 
     def create_dataset(
         self,
@@ -36,18 +40,18 @@ class Client:
         schema: Optional[Schema] = None,
         upsert: bool = True,
     ) -> None:
-        return self._api._create_dataset(
+        return self.api._create_dataset(
             dataset_id=dataset_id,
             schema={} if schema is None else schema,
             upsert=upsert,
         )
 
     def delete_dataset(self, dataset_id: str) -> None:
-        return self._api._delete_dataset(dataset_id=dataset_id)
+        return self.api._delete_dataset(dataset_id=dataset_id)
 
     def Dataset(self, dataset_id: str) -> Dataset:
         self.create_dataset(dataset_id=dataset_id)
-        return Dataset(api=self._api, dataset_id=dataset_id)
+        return Dataset(api=self.api, dataset_id=dataset_id)
 
     def SimpleWorkflow(
         self,
@@ -60,7 +64,7 @@ class Client:
         **kwargs
     ) -> SimpleWorkflow:
         return SimpleWorkflow(
-            credentials=self._credentials,
+            credentials=self.credentials,
             workflow_name=workflow_name,
             job_id=job_id,
             metadata=metadata,
@@ -74,15 +78,27 @@ class Client:
         """
         Insert temporary local media.
         """
-        data = self._api._get_temp_file_upload_url()
+        data = self.api._get_temp_file_upload_url()
         upload_url = data["upload_url"]
         download_url = data["download_url"]
         with open(file_path, "rb") as fn_byte:
             media_content = bytes(fn_byte.read())
         print({"media_content": media_content})
-        response = self._api._upload_temporary_media(
+        response = self.api._upload_temporary_media(
             presigned_url=upload_url,
             media_content=media_content,
         )
         print(response.content)
         return {"download_url": download_url}
+
+    def list_project_keys(self):
+        return self.api._list_project_keys()
+
+    def get_project_key(self, key: str, token: str):
+        return self.api._get_project_key(key=key, token=token)
+
+    def set_project_key(self, key: str, value: str):
+        return self.api._set_project_key(key=key, value=value)
+
+    def delete_project_key(self, key: str):
+        return self.api._delete_project_key(key=key)
